# mypy: disable-error-code=assignment

"""Class implementation for the x-axis settings.
"""

from typing import List
from typing import Optional
from typing import Union

from apysc._chart.axis_label_bold_mixin import AxisLabelBoldMixIn
from apysc._chart.axis_label_fill_alpha_mixin import AxisLabelFillAlphaMixIn
from apysc._chart.axis_label_fill_color_mixin import AxisLabelFillColorMixIn
from apysc._chart.axis_label_font_family_mixin import AxisLabelFontFamilyMixIn
from apysc._chart.axis_label_font_size_mixin import AxisLabelFontSizeMixIn
from apysc._chart.axis_label_italic_mixin import AxisLabelItalicMixIn
from apysc._chart.axis_line_alpha_mixin import AxisLineAlphaMixIn
from apysc._chart.axis_line_color_mixin import AxisLineColorMixIn
from apysc._chart.axis_line_thickness_mixin import AxisLineThicknessMixIn
from apysc._chart.is_display_axis_label_mixin import IsDisplayAxisLabelMixIn
from apysc._chart.tick_max_num_mixin import TickMaxNumMixIn
from apysc._chart.tick_text_bold_mixin import TickTextBoldMixIn
from apysc._chart.tick_text_fill_alpha_mixin import TickTextFillAlphaMixIn
from apysc._chart.tick_text_fill_color_mixin import TickTextFillColorMixIn
from apysc._chart.tick_text_font_family_mixin import TickTextFontFamilyMixIn
from apysc._chart.tick_text_font_size_mixin import TickTextFontSizeMixIn
from apysc._chart.tick_text_italic_mixin import TickTextItalicMixIn
from apysc._chart.x_axis_column_name_mixin import XAxisColumnNameMixIn
from apysc._chart.x_axis_label_position import XAxisLabelPosition
from apysc._chart.x_axis_label_position_mixin import XAxisLabelPositionMixIn
from apysc._color.color import Color
from apysc._color.colors import Colors
from apysc._type.array import Array
from apysc._type.boolean import Boolean
from apysc._type.int import Int
from apysc._type.number import Number
from apysc._type.string import String
from apysc._validation import arg_validation_decos


class XAxisSettings(
    XAxisColumnNameMixIn,
    TickMaxNumMixIn,
    TickTextFontSizeMixIn,
    TickTextFontFamilyMixIn,
    TickTextFillColorMixIn,
    TickTextFillAlphaMixIn,
    TickTextBoldMixIn,
    TickTextItalicMixIn,
    AxisLineColorMixIn,
    AxisLineThicknessMixIn,
    AxisLineAlphaMixIn,
    IsDisplayAxisLabelMixIn,
    XAxisLabelPositionMixIn,
    AxisLabelFontSizeMixIn,
    AxisLabelFontFamilyMixIn,
    AxisLabelFillColorMixIn,
    AxisLabelFillAlphaMixIn,
    AxisLabelBoldMixIn,
    AxisLabelItalicMixIn,
):
    # x_axis_column_name
    @arg_validation_decos.is_builtin_string(arg_position_index=1, optional=False)
    # tick_max_num
    @arg_validation_decos.is_integer(arg_position_index=2, optional=True)
    # tick_text_font_size
    @arg_validation_decos.is_integer(arg_position_index=3, optional=False)
    # tick_text_font_family
    @arg_validation_decos.is_builtin_str_list_or_apysc_str_arr(
        arg_position_index=4, optional=True
    )
    # tick_text_fill_color
    @arg_validation_decos.is_color(arg_position_index=5, optional=False)
    # tick_text_fill_alpha
    @arg_validation_decos.num_is_0_to_1_range(arg_position_index=6, optional=False)
    # tick_text_bold
    @arg_validation_decos.is_boolean(arg_position_index=7, optional=False)
    # tick_text_italic
    @arg_validation_decos.is_boolean(arg_position_index=8, optional=False)
    # line_color
    @arg_validation_decos.is_color(arg_position_index=9, optional=False)
    # line_thickness
    @arg_validation_decos.is_integer(arg_position_index=10, optional=False)
    @arg_validation_decos.num_is_gte_zero(arg_position_index=10, optional=False)
    # line_alpha
    @arg_validation_decos.is_num(arg_position_index=11, optional=False)
    @arg_validation_decos.num_is_0_to_1_range(arg_position_index=11, optional=False)
    # is_display_axis_label
    @arg_validation_decos.is_boolean(arg_position_index=12, optional=False)
    # axis_label_position
    @arg_validation_decos.is_x_axis_label_position(arg_position_index=13)
    # axis_label_font_size
    @arg_validation_decos.is_integer(arg_position_index=14, optional=False)
    @arg_validation_decos.num_is_gte_zero(arg_position_index=14, optional=False)
    # axis_label_font_family
    @arg_validation_decos.is_builtin_str_list_or_apysc_str_arr(
        arg_position_index=15, optional=True
    )
    # axis_label_fill_color
    @arg_validation_decos.is_color(arg_position_index=16, optional=False)
    # axis_label_fill_alpha
    @arg_validation_decos.num_is_0_to_1_range(arg_position_index=17, optional=False)
    # axis_label_bold
    @arg_validation_decos.is_boolean(arg_position_index=18, optional=False)
    # axis_label_italic
    @arg_validation_decos.is_boolean(arg_position_index=19, optional=False)
    # variable_name_suffix
    @arg_validation_decos.is_builtin_string(arg_position_index=20, optional=False)
    def __init__(
        self,
        *,
        x_axis_column_name: str,
        tick_max_num: Optional[Union[int, Int]] = None,
        tick_text_font_size: Union[int, Int] = 12,
        tick_text_font_family: Optional[Union[Array[String], List[str]]] = None,
        tick_text_fill_color: Color = Colors.GRAY_666666,
        tick_text_fill_alpha: Union[float, Number] = 1.0,
        tick_text_bold: Union[bool, Boolean] = False,
        tick_text_italic: Union[bool, Boolean] = False,
        line_color: Color = Colors.GRAY_666666,
        line_thickness: Union[int, Int] = 1,
        line_alpha: Union[float, Number] = 1.0,
        is_display_axis_label: Union[bool, Boolean] = True,
        axis_label_position: XAxisLabelPosition = XAxisLabelPosition.OUTER_RIGHT,
        axis_label_font_size: Union[int, Int] = 12,
        axis_label_font_family: Optional[Union[Array[String], List[str]]] = None,
        axis_label_fill_color: Color = Colors.GRAY_666666,
        axis_label_fill_alpha: Union[float, Number] = 1.0,
        axis_label_bold: Union[bool, Boolean] = False,
        axis_label_italic: Union[bool, Boolean] = False,
        variable_name_suffix: str = "",
    ) -> None:
        """
        X-axis settings class.

        Parameters
        ----------
        x_axis_column_name : str
            X-axis column name.
        tick_max_num : Optional[Union[int, Int]], optional
            A tick max display number. Often tick display number
            becomes under this value.
        tick_text_font_size : Union[int, Int], optional
            A tick text font-size setting.
        tick_text_font_family : Optional[Union[Array[String], List[str]]], optional
            A tick text font family setting.
            Each string in an array needs to be a font name (e.g., `Times New Roman`).
        tick_text_fill_color : Color, optional
            A tick text fill-color setting.
        tick_text_fill_alpha : Union[float, Number], optional
            A tick text fill-alpha setting.
        tick_text_bold : Union[bool, Boolean], optional
            A boolean, whether a tick text is a bold style or not.
        tick_text_italic : Union[bool, Boolean], optional
            A boolean, whether a tick text is an italic style or not (normal).
        line_color : Color, optional
            An axis line color setting.
        line_thickness : Union[int, Int], optional
            An axis line thickness (line width) setting.
        line_alpha : Union[float, Number], optional
            An axis line alpha setting.
        is_display_axis_label : Union[bool, Boolean], optional
            A boolean, whether an axis label is visible or not.
        axis_label_position : XAxisLabelPosition, optional
            An axis label position setting.
        axis_label_font_size : Union[int, Int], optional
            An axis label font size setting.
        axis_label_font_family : Optional[Union[Array[String], List[str]]], optional
            An axis label font family setting.
        axis_label_fill_color : Color, optional
            An axis label fill-color setting.
        axis_label_fill_alpha : Union[float, Number], optional
            An axis label fill-alpha setting.
        axis_label_bold : Union[bool, Boolean], optional
            A boolean, whether an axis label is a bold style or not.
        axis_label_italic : Union[bool, Boolean], optional
            A boolean, whether an axis label is an italic style or not (normal).
        variable_name_suffix : str, default ""
            A JavaScript variable name suffix string.
            This setting is sometimes useful for JavaScript debugging.
        """
        self._set_initial_x_axis_column_name(
            x_axis_column_name=x_axis_column_name,
        )
        self._set_initial_tick_max_num(
            tick_max_num=tick_max_num,
            variable_name_suffix=variable_name_suffix,
        )
        self._set_initial_tick_text_font_size(
            tick_text_font_size=tick_text_font_size,
            variable_name_suffix=variable_name_suffix,
        )
        self._set_initial_tick_text_font_family(
            tick_text_font_family=tick_text_font_family,
            variable_name_suffix=variable_name_suffix,
        )
        self._set_initial_tick_text_fill_color(
            tick_text_fill_color=tick_text_fill_color,
        )
        self._set_initial_tick_text_fill_alpha(
            tick_text_fill_alpha=tick_text_fill_alpha,
            variable_name_suffix=variable_name_suffix,
        )
        self._set_initial_tick_text_bold(
            tick_text_bold=tick_text_bold,
            variable_name_suffix=variable_name_suffix,
        )
        self._set_initial_tick_text_italic(
            tick_text_italic=tick_text_italic,
            variable_name_suffix=variable_name_suffix,
        )
        self._set_initial_line_color(
            line_color=line_color,
        )
        self._set_initial_line_thickness(
            line_thickness=line_thickness,
            variable_name_suffix=variable_name_suffix,
        )
        self._set_initial_line_alpha(
            line_alpha=line_alpha,
            variable_name_suffix=variable_name_suffix,
        )
        self._set_initial_is_display_axis_label(
            is_display_axis_label=is_display_axis_label,
            variable_name_suffix=variable_name_suffix,
        )
        self._set_initial_x_axis_label_position(
            x_axis_label_position=axis_label_position,
        )
        self._set_initial_axis_label_font_size(
            axis_label_font_size=axis_label_font_size,
            variable_name_suffix=variable_name_suffix,
        )
        self._set_initial_axis_label_font_family(
            axis_label_font_family=axis_label_font_family,
            variable_name_suffix=variable_name_suffix,
        )
        self._set_initial_axis_label_fill_color(
            axis_label_fill_color=axis_label_fill_color,
        )
        self._set_initial_axis_label_fill_alpha(
            axis_label_fill_alpha=axis_label_fill_alpha,
            variable_name_suffix=variable_name_suffix,
        )
        self._set_initial_axis_label_bold(
            axis_label_bold=axis_label_bold,
            variable_name_suffix=variable_name_suffix,
        )
        self._set_initial_axis_label_italic(
            axis_label_italic=axis_label_italic,
            variable_name_suffix=variable_name_suffix,
        )



"""This module is for the translation mapping data of the
following document:

Document file: mousedown_and_mouseup.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# mousedown and mouseup interfaces": "# mousedown と mouseup のインターフェイス",
    ##################################################
    "This page explains the `mousedown` and `mouseup` interfaces.": "このページでは`mousedown`や`mouseup`の各インターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interfaces are these?": "## 各インターフェイスの概要",
    ##################################################
    "The `mousedown` interface binds the event handler that the interface calls when a user mouse downed on a `DisplayObject` instance. Conversely, the `mouseup` interface binds the event handler that the interface calls when a user mouse upped on a `DisplayObject` one.": "`mousedown`インターフェイスは`DisplayObject`のインスタンス上でマウスを押した時のイベントのハンドラを設定するためのインターフェイスです。逆に`mouseup`インターフェイスはマウスから指を離した（押している状態を解除した）時のイベントのハンドラを設定するためのインターフェイスです。",  # noqa
    ##################################################
    "## See also": "## 関連資料",
    ##################################################
    "The following page describes the basic mouse event interfaces:": "以下のページでは基本的なマウスイベントのインターフェイスについて説明しています:",  # noqa
    ##################################################
    "- [Basic mouse event interfaces](mouse_event_basic.md)": "- [基本的なマウスイベントの各インターフェイス](jp_mouse_event_basic.md)",  # noqa
    ##################################################
    "## Basic usage of the mousedown and mouseup interfaces": "## mousedown と mouseup のインターフェイスの基本的な使い方",  # noqa
    ##################################################
    "Each `DisplayObject` instance has the `mousedown` and `mouseup` method interfaces, and you can bind handlers by these.": "`DisplayObject`の各インスタンスは`mousedown`と`mouseup`のメソッドのインターフェイスを持っており、それらを使ってハンドラを設定することができます。",  # noqa
    ##################################################
    "The following example binds the mouse down handler and mouse upped one to the rectangle. The handler changes the rectangle color when the mouse downs and reverts to the original one when the mouse upped.": "以下のコード例では四角に対してマウスを押した時と離した時のハンドラをそれぞれ設定しています。ハンドラではマウスを押した時に四角の色を変更し、マウスを離した時に元の色に戻しています。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\n\ndef on_mousedown(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the rectangle calls when mousedown.\n\n    Parameters\n    ----------\n    e : MouseEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = e.this\n    rectangle.fill_color = ap.Color("#f0a")\n\n\ndef on_mouseup(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the rectangle calls when mouseup.\n\n    Parameters\n    ----------\n    e : MouseEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = e.this\n    rectangle.fill_color = ap.Color("#0af")\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\n\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\n# Bind each handler to the rectangle.\nrectangle.mousedown(on_mousedown)\nrectangle.mouseup(on_mouseup)\n\nap.save_overall_html(dest_dir_path="mousedown_and_mouseup_basic_usage/")\n```': '```py\n# runnable\nimport apysc as ap\n\n\ndef on_mousedown(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the rectangle calls when mousedown.\n\n    Parameters\n    ----------\n    e : MouseEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = e.this\n    rectangle.fill_color = ap.Color("#f0a")\n\n\ndef on_mouseup(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the rectangle calls when mouseup.\n\n    Parameters\n    ----------\n    e : MouseEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = e.this\n    rectangle.fill_color = ap.Color("#0af")\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\n\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\n# Bind each handler to the rectangle.\nrectangle.mousedown(on_mousedown)\nrectangle.mouseup(on_mouseup)\n\nap.save_overall_html(dest_dir_path="mousedown_and_mouseup_basic_usage/")\n```',  # noqa
    ##################################################
    "## Unbind interfaces": "## 解除用のインターフェイス",
    ##################################################
    "The `unbind_mousedown` and `unbind_mouseup` interfaces unbind each registered handler from the `DisplayObject`\\.": "`unbind_mousedown`と`unbind_mouseup`は`DisplayObject`のインスタンスから設定されているハンドラの設定を解除します。",  # noqa
    ##################################################
    "The following example unbinds handlers in the `on_mousedown` and `on_mouseup` functions so that the rectangle calls these handlers only once.": "以下のコード例では`on_mousedown`と`on_mouseup`の各ハンドラ内でハンドラの設定を解除しているためハンドラの処理は1回のみ実行されます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\n\ndef on_mousedown(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the rectangle calls when mousedown.\n\n    Parameters\n    ----------\n    e : MouseEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = e.this\n    rectangle.unbind_mousedown(handler=on_mousedown)\n    rectangle.fill_color = ap.Color("#f0a")\n\n\ndef on_mouseup(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the rectangle calls when mouseup.\n\n    Parameters\n    ----------\n    e : MouseEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = e.this\n    rectangle.unbind_mouseup(handler=on_mouseup)\n    rectangle.fill_color = ap.Color("#0af")\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\n\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nrectangle.mousedown(on_mousedown)\nrectangle.mouseup(on_mouseup)\n\nap.save_overall_html(dest_dir_path="mousedown_and_mouseup_unbind_interfaces/")\n```': '```py\n# runnable\nimport apysc as ap\n\n\ndef on_mousedown(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the rectangle calls when mousedown.\n\n    Parameters\n    ----------\n    e : MouseEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = e.this\n    rectangle.unbind_mousedown(handler=on_mousedown)\n    rectangle.fill_color = ap.Color("#f0a")\n\n\ndef on_mouseup(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n    """\n    The handler that the rectangle calls when mouseup.\n\n    Parameters\n    ----------\n    e : MouseEvent\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    rectangle: ap.Rectangle = e.this\n    rectangle.unbind_mouseup(handler=on_mouseup)\n    rectangle.fill_color = ap.Color("#0af")\n\n\nap.Stage(\n    background_color=ap.Color("#333"),\n    stage_width=150,\n    stage_height=150,\n    stage_elem_id="stage",\n)\n\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nrectangle: ap.Rectangle = sprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nrectangle.mousedown(on_mousedown)\nrectangle.mouseup(on_mouseup)\n\nap.save_overall_html(dest_dir_path="mousedown_and_mouseup_unbind_interfaces/")\n```',  # noqa
    ##################################################
    "There are also existing the `unbind_mousedown_all` and `unbind_mouseup_all` interfaces. These interfaces unbind all the handlers from the target `DisplayObject` instance.": "また、`unbind_mousedown_all`や`unbind_mouseup_all`などのインターフェイスも存在します。これらのインターフェイスは`DisplayObject`のインスタンスから該当のイベントのハンドラ設定を全て取り除きます。",  # noqa
    ##################################################
    "## mousedown API": "## mousedown API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Add mouse down event listener setting.<hr>": "マウスのボタンを押した時のイベント設定を追加します。<hr>",
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `handler`: _Handler": "- `handler`: _Handler",
    ##################################################
    "  - Callable that would be called when mouse down on this instance.": "  - インスタンス上でマウスのボタンを押した時に呼ばれる関数もしくはメソッド。",  # noqa
    ##################################################
    "- `options`: dict or None, default None": "- `options`: dict or None, default None",  # noqa
    ##################################################
    "  - Optional arguments dictionary to be passed to a handler.": "  - ハンドラに渡される省略が可能な追加のパラメーターとしての辞書。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `name`: str": "- `name`: str",
    ##################################################
    "  - Handler's name.": "  - ハンドラ名。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> def on_mousedown(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.Color("#f0a")\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> _ = rectangle.mousedown(on_mousedown)\n```': '```py\n>>> import apysc as ap\n>>> def on_mousedown(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.Color("#f0a")\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> _ = rectangle.mousedown(on_mousedown)\n```',  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [About the handler options' type](https://simon-ritchie.github.io/apysc/en/about_handler_options_type.html)": "- [ハンドラのoptions引数の型について](https://simon-ritchie.github.io/apysc/jp/jp_about_handler_options_type.html)",  # noqa
    ##################################################
    "## unbind_mousedown API": "## unbind_mousedown API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Unbind a specified handler's mouse down event.<hr>": "マウスのボタンを押した際のイベントの指定されたハンドラ設定を解除します。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `handler`: _Handler": "- `handler`: _Handler",
    ##################################################
    "  - Unbinding target Callable.": "  - イベント設定を取り除く対象の関数やメソッドなど。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> def on_mousedown(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.Color("#f0a")\n...     rectangle.unbind_mousedown(on_mousedown)\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> _ = rectangle.mousedown(on_mousedown)\n```': '```py\n>>> import apysc as ap\n>>> def on_mousedown(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.Color("#f0a")\n...     rectangle.unbind_mousedown(on_mousedown)\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> _ = rectangle.mousedown(on_mousedown)\n```',  # noqa
    ##################################################
    "## unbind_mousedown_all API": "## unbind_mousedown_all API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Unbind all mouse down events.<hr>": "マウスのボタンを押した時のイベントの全てのハンドラ設定を解除します。<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> def on_mousedown(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.Color("#f0a")\n...     rectangle.unbind_mousedown_all()\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> _ = rectangle.mousedown(on_mousedown)\n```': '```py\n>>> import apysc as ap\n>>> def on_mousedown(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.Color("#f0a")\n...     rectangle.unbind_mousedown_all()\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> _ = rectangle.mousedown(on_mousedown)\n```',  # noqa
    ##################################################
    "## mouseup API": "## mouseup API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Add mouse up event listener setting.<hr>": "マウスのボタンを離した時のイベント設定を追加します。<hr>",
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `handler`: _Handler": "- `handler`: _Handler",
    ##################################################
    "  - Callable that would be called when mouse-up on this instance.": "  - インスタンス上でマウスのボタンを離した時に呼ばれる関数もしくはメソッド。",  # noqa
    ##################################################
    "- `options`: dict or None, default None": "- `options`: dict or None, default None",  # noqa
    ##################################################
    "  - Optional arguments dictionary to be passed to a handler.": "  - ハンドラに渡される省略が可能な追加のパラメーターとしての辞書。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `name`: str": "- `name`: str",
    ##################################################
    "  - Handler's name.": "  - ハンドラ名。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> def on_mouseup(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.Color("#f0a")\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> _ = rectangle.mouseup(on_mouseup)\n```': '```py\n>>> import apysc as ap\n>>> def on_mouseup(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.Color("#f0a")\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> _ = rectangle.mouseup(on_mouseup)\n```',  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [About the handler options' type](https://simon-ritchie.github.io/apysc/en/about_handler_options_type.html)": "- [ハンドラのoptions引数の型について](https://simon-ritchie.github.io/apysc/jp/jp_about_handler_options_type.html)",  # noqa
    ##################################################
    "## unbind_mouseup API": "## unbind_mouseup API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Unbind a specified handler's mouse-up event.<hr>": "マウスのボタンを離した際のイベントの指定されたハンドラ設定を解除します。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `handler`: _Handler": "- `handler`: _Handler",
    ##################################################
    "  - Unbinding target Callable.": "  - イベント設定を取り除く対象の関数やメソッドなど。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> def on_mouseup(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.Color("#f0a")\n...     rectangle.unbind_mouseup(on_mouseup)\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> _ = rectangle.mouseup(on_mouseup)\n```': '```py\n>>> import apysc as ap\n>>> def on_mouseup(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.Color("#f0a")\n...     rectangle.unbind_mouseup(on_mouseup)\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> _ = rectangle.mouseup(on_mouseup)\n```',  # noqa
    ##################################################
    "## unbind_mouseup_all API": "## unbind_mouseup_all API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Unbind all mouse up events.<hr>": "マウスのボタンを離したとぎのイベントの全てのハンドラ設定を解除します。<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> def on_mouseup(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.Color("#f0a")\n...     rectangle.unbind_mouseup_all()\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> _ = rectangle.mouseup(on_mouseup)\n```': '```py\n>>> import apysc as ap\n>>> def on_mouseup(e: ap.MouseEvent[ap.Rectangle], options: dict) -> None:\n...     rectangle: ap.Rectangle = e.this\n...     rectangle.fill_color = ap.Color("#f0a")\n...     rectangle.unbind_mouseup_all()\n>>> stage: ap.Stage = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"))\n>>> rectangle: ap.Rectangle = sprite.graphics.draw_rect(\n...     x=50, y=50, width=50, height=50\n... )\n>>> _ = rectangle.mouseup(on_mouseup)\n```',  # noqa
}



"""The class implementation for the `schedule_send` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialScheduleSendIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `schedule_send` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M16.5 12.5H15v4l3 2 .75-1.23-2.25-1.52V12.5zM16 9L2 3v7l9 2-9 2v7l7.27-3.11C10.09 20.83 12.79 23 16 23c3.86 0 7-3.14 7-7s-3.14-7-7-7zm0 12c-2.75 0-4.98-2.22-5-4.97v-.07c.02-2.74 2.25-4.97 5-4.97 2.76 0 5 2.24 5 5S18.76 21 16 21z"/></svg>'  # noqa



"""The class implementation for the outlined `watch_later` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialWatchLaterOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `watch_later` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24" x="0"/></g><g><g><path d="M12,2C6.5,2,2,6.5,2,12s4.5,10,10,10s10-4.5,10-10S17.5,2,12,2z M12,20c-4.41,0-8-3.59-8-8s3.59-8,8-8s8,3.59,8,8 S16.41,20,12,20z M12.5,7H11v6l5.2,3.2l0.8-1.3l-4.5-2.7V7z"/></g></g></svg>'  # noqa



"""This module is for the translation mapping data of the
following document:

Document file: datetime_day.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# DateTime class day property": "# DateTime クラスの day 属性",
    ##################################################
    "This page explains the `DateTime` class's `day` property interface.": "このページでは`DateTime`クラスの`day`属性のインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "The `day` property gets or sets a day value.": "`day`属性では日の値の取得もしくは設定を行うことができます。",
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "A `DateTime` instance has its property interface.": "`DateTime`クラスのインスタンスがその属性のインターフェイスを持っています。",  # noqa
    ##################################################
    "Its getter interface returns a day's `Int` value.": "そのインターフェイスのgetterでは`Int`型の日の値を返却します。",  # noqa
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\ndatetime_: ap.DateTime = ap.DateTime(year=2022, month=12, day=5)\nday: ap.Int = datetime_.day\nassert day == 5\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\ndatetime_: ap.DateTime = ap.DateTime(year=2022, month=12, day=5)\nday: ap.Int = datetime_.day\nassert day == 5\n```",  # noqa
    ##################################################
    "Also, its setter interface accepts a day's `Int` value.": "また、setterのインターフェイスでは同様に`Int`型の値を受け付けます。",  # noqa
    ##################################################
    "1-31 integer is acceptable.": "1～31の整数を受け付けることができます。",
    ##################################################
    "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\ndatetime_: ap.DateTime = ap.DateTime(year=2022, month=12, day=5)\ndatetime_.day = ap.Int(10)\nassert datetime_.day == 10\n```": "```py\n# runnable\nimport apysc as ap\n\nap.Stage()\ndatetime_: ap.DateTime = ap.DateTime(year=2022, month=12, day=5)\ndatetime_.day = ap.Int(10)\nassert datetime_.day == 10\n```",  # noqa
    ##################################################
    "## day property API": "## day 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get a current day's value.<hr>": "現在の日の値を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `day`: Int": "- `day`: Int",
    ##################################################
    "  - A current-day value.": "  - 現在の日の値。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    "```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> datetime_: ap.DateTime = ap.DateTime(year=2022, month=12, day=1)\n>>> datetime_.day\nInt(1)\n\n>>> datetime_.day = ap.Int(2)\n>>> datetime_.day\nInt(2)\n```": "```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> datetime_: ap.DateTime = ap.DateTime(year=2022, month=12, day=1)\n>>> datetime_.day\nInt(1)\n\n>>> datetime_.day = ap.Int(2)\n>>> datetime_.day\nInt(2)\n```",  # noqa
}



"""The mix-in class implementation for the `for`-loop `__exit__` method.
"""

from typing import Any
from typing import Dict

from typing_extensions import final

from apysc._expression.indent_num import Indent
from apysc._html.debug_mode import add_debug_info_setting


class ForLoopExitMixIn:
    _locals: Dict[str, Any]
    _globals: Dict[str, Any]
    _snapshot_name: str
    _indent: Indent

    @final
    @add_debug_info_setting(module_name=__name__)
    def __exit__(self, *args: Any) -> None:
        """
        The exiting method for the beginning of with-statement.
        """
        from apysc._expression import expression_data_util
        from apysc._expression import last_scope
        from apysc._expression.get_last_scope_interface import GetLastScopeInterface
        from apysc._loop import loop_count
        from apysc._type import revert_mixin

        loop_count.decrement_current_loop_count()
        revert_mixin.revert_each_scope_vars(
            snapshot_name=self._snapshot_name,
            locals_=self._locals,
            globals_=self._globals,
        )
        self._indent.__exit__()
        expression_data_util.append_js_expression(expression="}")
        if isinstance(self, GetLastScopeInterface):
            last_scope.set_last_scope(value=self._get_last_scope())
        else:
            raise TypeError(
                "This interface is only available a `GetLastScopeInterface` "
                f"subclass: {type(self).__name__}, {self}"
            )



"""The class implementation for the `build_circle` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialBuildCircleIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `build_circle` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24"/></g><g><g><path d="M12,2C6.48,2,2,6.48,2,12c0,5.52,4.48,10,10,10s10-4.48,10-10 C22,6.48,17.52,2,12,2z M16.9,15.49l-1.4,1.4c-0.2,0.2-0.51,0.2-0.71,0l-3.41-3.41c-1.22,0.43-2.64,0.17-3.62-0.81 c-1.11-1.11-1.3-2.79-0.59-4.1l2.35,2.35l1.41-1.41L8.58,7.17c1.32-0.71,2.99-0.52,4.1,0.59c0.98,0.98,1.24,2.4,0.81,3.62 l3.41,3.41C17.09,14.98,17.09,15.3,16.9,15.49z" fill-rule="evenodd"/></g></g></svg>'  # noqa



"""The mix-in class implementation for the `y_axis_label_position` value.
"""

from typing_extensions import final

from apysc._chart.y_axis_label_position import YAxisLabelPosition
from apysc._html.debug_mode import add_debug_info_setting
from apysc._validation import arg_validation_decos


class YAxisLabelPositionMixIn:
    _y_axis_label_position: YAxisLabelPosition

    @final
    @arg_validation_decos.is_y_axis_label_position(arg_position_index=1)
    @add_debug_info_setting(module_name=__name__)
    def _set_initial_y_axis_label_position(
        self,
        *,
        y_axis_label_position: YAxisLabelPosition,
    ) -> None:
        """
        Set an initial y-axis label position setting.

        Parameters
        ----------
        y_axis_label_position : YAxisLabelPosition
            A y-axis label position setting.
        """
        self._y_axis_label_position = y_axis_label_position



"""The class implementation for the outlined `loyalty` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialLoyaltyOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `loyalty` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M21.41 11.58l-9-9C12.05 2.22 11.55 2 11 2H4c-1.1 0-2 .9-2 2v7c0 .55.22 1.05.59 1.42l9 9c.36.36.86.58 1.41.58s1.05-.22 1.41-.59l7-7c.37-.36.59-.86.59-1.41s-.23-1.06-.59-1.42zM13 20.01L4 11V4h7v-.01l9 9-7 7.02z"/><circle cx="6.5" cy="6.5" r="1.5"/><path d="M8.9 12.55c0 .57.23 1.07.6 1.45l3.5 3.5 3.5-3.5c.37-.37.6-.89.6-1.45 0-1.13-.92-2.05-2.05-2.05-.57 0-1.08.23-1.45.6l-.6.6-.6-.59c-.37-.38-.89-.61-1.45-.61-1.13 0-2.05.92-2.05 2.05z"/></svg>'  # noqa



"""The class implementation for the outlined `offline_bolt` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialOfflineBoltOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `offline_bolt` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0z" fill="none"/><path d="M12 2.02c-5.51 0-9.98 4.47-9.98 9.98s4.47 9.98 9.98 9.98 9.98-4.47 9.98-9.98S17.51 2.02 12 2.02zm0 17.96c-4.4 0-7.98-3.58-7.98-7.98S7.6 4.02 12 4.02 19.98 7.6 19.98 12 16.4 19.98 12 19.98zM12.75 5l-4.5 8.5h3.14V19l4.36-8.5h-3z"/></svg>'  # noqa



"""This module is for the translation mapping data of the
following document:

Document file: graphics_draw_triangle.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Graphics draw_triangle interface": "# Graphics クラスの draw_triangle インターフェイス",
    ##################################################
    "This page explains the `Graphics` class `draw_triangle` method interface.": "このページでは`Graphics`クラスの`draw_triangle`メソッドのインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "The `draw_triangle` interface draws vector triangle graphics.": "`draw_triangle`インターフェイスは三角形のベクターグラフィックスを描画します。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `draw_triangle` interface requires the `x1`, `y1`, `x2`, `y2`, `x3`, and `y3` arguments.": "`draw_triangle`インターフェイスは`x1`, `y1`, `x2`, `y2`, `x3`, `y3`の各引数の指定を必要とします。",  # noqa
    ##################################################
    "The `x1` and `y1` arguments are the first vertex coordinate of a triangle.": "`x1`と`y1`の引数は三角形の1つ目の頂点の座標となります。",  # noqa
    ##################################################
    "The `x2` and `y2` are the second vertex coordinate, and the `x3` and `y3` are the third.": "`x2`と`y2`は2つ目の頂点の座標となり、`x3`と`y3`は3つ目の頂点の座標となりま。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=150,\n    stage_height=150,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\ntriangle: ap.Triangle = sprite.graphics.draw_triangle(\n    x1=75,\n    y1=50,\n    x2=50,\n    y2=100,\n    x3=100,\n    y3=100,\n)\n\nap.save_overall_html(dest_dir_path="./graphics_draw_triangle_basic_usage/")\n```': '```py\n# runnable\nimport apysc as ap\n\nap.Stage(\n    stage_width=150,\n    stage_height=150,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\ntriangle: ap.Triangle = sprite.graphics.draw_triangle(\n    x1=75,\n    y1=50,\n    x2=50,\n    y2=100,\n    x3=100,\n    y3=100,\n)\n\nap.save_overall_html(dest_dir_path="./graphics_draw_triangle_basic_usage/")\n```',  # noqa
    ##################################################
    "## Triangle instance": "## Triangle インスタンス",
    ##################################################
    "The `draw_triangle` interface returns a `Triangle` instance.": "`draw_triangle`インターフェイスは`Triangle`クラスのインスタンスを返却します。",  # noqa
    ##################################################
    "You can update each setting or bind events.": "そのインスタンスを使って各種設定を更新したりイベントの設定などを行うことができます。",  # noqa
    ##################################################
    "For instance, the following example sets the mouse event to the `Triangle` instance and updates the x-coordinate in the `on_click` handler:": "例えば、以下の例では`Triangle`のインスタンスにマウスイベントを設定し、`on_click`のハンドラ内でX座標の更新を行っています:",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\n\ndef on_click(e: ap.MouseEvent[ap.Triangle], options: dict) -> None:\n    """\n    The handler for the click event.\n\n    Parameters\n    ----------\n    e : ap.MouseEvent[ap.Rectangle]\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    triangle: ap.Triangle = e.this\n    triangle.x += 2\n\n\nap.Stage(\n    stage_width=150,\n    stage_height=150,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\ntriangle: ap.Triangle = sprite.graphics.draw_triangle(\n    x1=75,\n    y1=50,\n    x2=50,\n    y2=100,\n    x3=100,\n    y3=100,\n)\ntriangle.click(handler=on_click)\n\nap.save_overall_html(dest_dir_path="./graphics_draw_triangle_triangle_instance/")\n```': '```py\n# runnable\nimport apysc as ap\n\n\ndef on_click(e: ap.MouseEvent[ap.Triangle], options: dict) -> None:\n    """\n    The handler for the click event.\n\n    Parameters\n    ----------\n    e : ap.MouseEvent[ap.Rectangle]\n        Event instance.\n    options : dict\n        Optional arguments dictionary.\n    """\n    triangle: ap.Triangle = e.this\n    triangle.x += 2\n\n\nap.Stage(\n    stage_width=150,\n    stage_height=150,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\nsprite: ap.Sprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\ntriangle: ap.Triangle = sprite.graphics.draw_triangle(\n    x1=75,\n    y1=50,\n    x2=50,\n    y2=100,\n    x3=100,\n    y3=100,\n)\ntriangle.click(handler=on_click)\n\nap.save_overall_html(dest_dir_path="./graphics_draw_triangle_triangle_instance/")\n```',  # noqa
    ##################################################
    "## draw_triangle API": "## draw_triangle のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Draw a triangle vector graphic.<hr>": "三角形のベクターグラフィックスを描画します。<hr>",
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `x1`: Union[float, Number]": "- `x1`: Union[float, Number]",
    ##################################################
    "  - First vertex's x coordinate.": "  - 1つ目の頂点のX座標。",
    ##################################################
    "- `y1`: Union[float, Number]": "- `y1`: Union[float, Number]",
    ##################################################
    "  - First vertex's y coordinate.": "  - 1つ目の頂点のY座標。",
    ##################################################
    "- `x2`: Union[float, Number]": "- `x2`: Union[float, Number]",
    ##################################################
    "  - Second vertex's x coordinate.": "  - 2つ目の頂点のX座標。",
    ##################################################
    "- `y2`: Union[float, Number]": "- `y2`: Union[float, Number]",
    ##################################################
    "  - Second vertex's y coordinate.": "  - 2つ目の頂点のY座標。",
    ##################################################
    "- `x3`: Union[float, Number]": "- `x3`: Union[float, Number]",
    ##################################################
    "  - Third vertex's x coordinate.": "  - 3つ目の頂点のX座標。",
    ##################################################
    "- `y3`: Union[float, Number]": "- `y3`: Union[float, Number]",
    ##################################################
    "  - Third vertex's y coordinate.": "  - 3つ目の頂点のY座標。",
    ##################################################
    "- `variable_name_suffix`: str, optional": "- `variable_name_suffix`: str, optional",  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `triangle`: Triangle": "- `triangle`: Triangle",
    ##################################################
    "  - Created triangle graphics instance.": "  - 生成された三角形のグラフィックスのインスタンス。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"), alpha=0.7)\n>>> sprite.graphics.line_style(color=ap.Color("#fff"), thickness=5, alpha=0.5)\n>>> triangle: ap.Triangle = sprite.graphics.draw_triangle(\n...     x1=75,\n...     y1=50,\n...     x2=25,\n...     y2=100,\n...     x3=100,\n...     y3=100,\n... )\n>>> triangle.x1\nNumber(75.0)\n\n>>> triangle.y1 = ap.Number(30)\n>>> triangle.y1\nNumber(30.0)\n\n>>> triangle.fill_color\nColor("#00aaff")\n```': '```py\n>>> import apysc as ap\n>>> _ = ap.Stage()\n>>> sprite: ap.Sprite = ap.Sprite()\n>>> sprite.graphics.begin_fill(color=ap.Color("#0af"), alpha=0.7)\n>>> sprite.graphics.line_style(color=ap.Color("#fff"), thickness=5, alpha=0.5)\n>>> triangle: ap.Triangle = sprite.graphics.draw_triangle(\n...     x1=75,\n...     y1=50,\n...     x2=25,\n...     y2=100,\n...     x3=100,\n...     y3=100,\n... )\n>>> triangle.x1\nNumber(75.0)\n\n>>> triangle.y1 = ap.Number(30)\n>>> triangle.y1\nNumber(30.0)\n\n>>> triangle.fill_color\nColor("#00aaff")\n```',  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[References]**": "**[関連資料]**",
    ##################################################
    "- [Triangle class](https://simon-ritchie.github.io/apysc/en/triangle.html)": "- [Triangle クラス](https://simon-ritchie.github.io/apysc/jp/jp_triangle.html)",  # noqa
}



"""The left x geometry mix-in implementation for the `RectangleGeom`.
"""

from apysc._html.debug_mode import add_debug_info_setting
from apysc._type.number import Number


class RectangleGeomLeftXMixIn:
    _left_x: Number

    @property
    @add_debug_info_setting(module_name=__name__)
    def left_x(self) -> Number:
        """
        Get the rectangle left x coordinate.

        Returns
        -------
        left_x : Number
            The rectangle left x coordinate.
        """
        return self._left_x



"""This module is for the translation mapping data of the
following document:

Document file: string_slice.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# String class slice method": "# String クラスの slice メソッド",
    ##################################################
    "This page explains the `String` class `slice` method.": "このページでは`String`クラスの`slice`メソッドについて説明します。",  # noqa
    ##################################################
    "## What method is this?": "## メソッド概要",
    ##################################################
    "The `slice` method slices a string with the specified start and end indices.": "`slice`メソッドはインデックスの開始と終了の指定値を使って文字列をスライス（文字列の一部の抽出を）します。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The `slice` method requires the `start` and `end` arguments.": "`slice`メソッドは`start`と`end`の2つの引数を必要とします。",  # noqa
    ##################################################
    "The `start` argument is the starting index of slicing.": "`start`引数はスライスの開始インデックスです。",  # noqa
    ##################################################
    "Similarly, the `end` argument is the end index of slicing, with the range being up to (but not including) this index.": "同様に、`end`引数はスライスの終点のインデックスの指定となります。スライス範囲の最後はこのインデックス（ただしこのインデックス自体は含みません）が使われます。",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    stage_width=0,\n    stage_height=0,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\n\nstring: ap.String = ap.String("012345")\nresult_string: ap.String = string.slice(start=0)\nap.assert_equal(result_string, "012345")\n\nresult_string = string.slice(start=1)\nap.assert_equal(result_string, "12345")\n\nresult_string = string.slice(start=0, end=2)\nap.assert_equal(result_string, "01")\n\nresult_string = string.slice(start=2, end=4)\nap.assert_equal(result_string, "23")\n\nresult_string = string.slice(start=-2)\nap.assert_equal(result_string, "45")\n\nresult_string = string.slice(start=-3, end=-1)\nap.assert_equal(result_string, "34")\n\nap.save_overall_html(dest_dir_path="string_slice_basic_usage/")\n```': '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    stage_width=0,\n    stage_height=0,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\n\nstring: ap.String = ap.String("012345")\nresult_string: ap.String = string.slice(start=0)\nap.assert_equal(result_string, "012345")\n\nresult_string = string.slice(start=1)\nap.assert_equal(result_string, "12345")\n\nresult_string = string.slice(start=0, end=2)\nap.assert_equal(result_string, "01")\n\nresult_string = string.slice(start=2, end=4)\nap.assert_equal(result_string, "23")\n\nresult_string = string.slice(start=-2)\nap.assert_equal(result_string, "45")\n\nresult_string = string.slice(start=-3, end=-1)\nap.assert_equal(result_string, "34")\n\nap.save_overall_html(dest_dir_path="string_slice_basic_usage/")\n```',  # noqa
    ##################################################
    "## slice method API": "## slice メソッドのAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get a sliced string based on the specified arguments range.<hr>": "指定された引数の範囲に基づいてスライスされた文字列を取得します。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    '- `start`: Union[int, "Int"]': '- `start`: Union[int, "Int"]',
    ##################################################
    "  - A start index of the slice range.": "  - スライス範囲の開始インデックス。",
    ##################################################
    '- `end`: Optional[Union[int, "Int"]], optional': '- `end`: Optional[Union[int, "Int"]], optional',  # noqa
    ##################################################
    "  - An end index of the slice range. If this argument is not specified, this method skips the end position's slicing.": "  - スライス範囲の終了インデックス。もしもこの引数が指定されなかった場合、このメソッドは終了位置のスライスをスキップします。",  # noqa
    ##################################################
    '- `variable_name_suffix`: str, default ""': '- `variable_name_suffix`: str, default ""',  # noqa
    ##################################################
    "  - A JavaScript variable name suffix string. This setting is sometimes useful for JavaScript debugging.": "  - JavaScript上の変数のサフィックスの設定です。この設定はJavaScriptのデバッグ時に役立つことがあります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `result`: String": "- `result`: String",
    ##################################################
    "  - A sliced result string.": "  - スライス結果の文字列。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     stage_width=0,\n...     stage_height=0,\n...     background_color=ap.Color("#333"),\n...     stage_elem_id="stage",\n... )\n>>> string: ap.String = ap.String("012345")\n>>> result_string: ap.String = string.slice(start=0)\n>>> result_string\nString("012345")\n\n>>> result_string = string.slice(start=1)\n>>> result_string\nString("12345")\n\n>>> result_string = string.slice(start=0, end=2)\n>>> result_string\nString("01")\n\n>>> result_string = string.slice(start=2, end=4)\n>>> result_string\nString("23")\n\n>>> result_string = string.slice(start=-2)\n>>> result_string\nString("45")\n\n>>> result_string = string.slice(start=-3, end=-1)\n>>> result_string\nString("34")\n```': '```py\n>>> import apysc as ap\n>>> stage: ap.Stage = ap.Stage(\n...     stage_width=0,\n...     stage_height=0,\n...     background_color=ap.Color("#333"),\n...     stage_elem_id="stage",\n... )\n>>> string: ap.String = ap.String("012345")\n>>> result_string: ap.String = string.slice(start=0)\n>>> result_string\nString("012345")\n\n>>> result_string = string.slice(start=1)\n>>> result_string\nString("12345")\n\n>>> result_string = string.slice(start=0, end=2)\n>>> result_string\nString("01")\n\n>>> result_string = string.slice(start=2, end=4)\n>>> result_string\nString("23")\n\n>>> result_string = string.slice(start=-2)\n>>> result_string\nString("45")\n\n>>> result_string = string.slice(start=-3, end=-1)\n>>> result_string\nString("34")\n```',  # noqa
}



"""This module is for the translation mapping data of the
following document:

Document file: display_on_jupyter.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# display_on_jupyter interface": "# display_on_jupyter インターフェイス",
    ##################################################
    "This page explains the `display_on_jupyter` function interface.": "このページでは`display_on_jupyter`関数のインターフェイスについて説明します。",  # noqa
    ##################################################
    "## What interface is this?": "## インターフェイス概要",
    ##################################################
    "The `display_on_jupyter` interface displays the apysc HTML on the Jupyter.": "`display_on_jupyter`関数はapyscによって生成されたHTMLをJupyter上で表示します。",  # noqa
    ##################################################
    "## Requirements": "## 必要とされるインストールなどの対応",
    ##################################################
    "This interface requires the Jupyter library. Therefore, if you haven't installed Jupyter, you need to install it before going on (e.g., `pip install notebook`).": "このインターフェイスはJupyterのライブラリの事前のインストールが必要です。もしインストールされていなければ`pip install notebook`などのコマンドでインストールしておく必要があります。",  # noqa
    ##################################################
    "For more information, please see:": "詳細は以下をご確認ください:",
    ##################################################
    "- [Installing the Jupyter Software](https://jupyter.org/install)": "- [Installing the Jupyter Software](https://jupyter.org/install)",  # noqa
    ##################################################
    "Also, this interface uses the `IPython.display.IFrame` interface. If you encountered that interface error, please update the Jupyter version.": "また、このインターフェイスは`IPython.display.IFrame`のインターフェイスを使用しています。もしも該当のインターフェイス関係でエラーが発生した場合Jupyterのアップデートをお試しください。",  # noqa
    ##################################################
    "## Notes": "## 特記事項",
    ##################################################
    "- Jupyter on the VS Code is not supported currently (since the VS code restriction).": "- VS Code上のJupyterは現在サポートされていません（VS Code上の制限に起因するため将来サポートするかどうかは未定です）。",  # noqa
    ##################################################
    "- Jupyter notebook and JupyterLab are supported.": "- Jupyter notebook 及び JupyterLabはサポートしています。",  # noqa
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "You can use the `display_on_jupyter` interface to display an output HTML instead of the `save_overall_html` function.": "出力結果のHTMLをJupyter上で表示するために`save_overall_html`関数の代わりに`display_on_jupyter`を使用することができます。",  # noqa
    ##################################################
    "This interface requires the `html_file_name` argument to be unique if you need to output multiple HTML. Otherwise, this interface overwrites the HTML file:": "このインターフェイスは複数のHTMLファイルを保存する際にファイル名が被らないようにするために`html_file_name`引数にユニークなファイル名の指定が必要です。この値にユニークな値を指定しない場合HTMLが上書きされてしまいます。",  # noqa
    ##################################################
    '```py\nimport apysc as ap\n\nap.Stage(\n    stage_width=250,\n    stage_height=150,\n    background_color=ap.Color("#333"),\n)\nsprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nsprite.graphics.begin_fill(color=ap.Color("#f0a"))\nsprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\n\nap.display_on_jupyter(html_file_name="jupyter_sample_1.html")\n```': '```py\nimport apysc as ap\n\nap.Stage(\n    stage_width=250,\n    stage_height=150,\n    background_color=ap.Color("#333"),\n)\nsprite = ap.Sprite()\nsprite.graphics.begin_fill(color=ap.Color("#0af"))\nsprite.graphics.draw_rect(x=50, y=50, width=50, height=50)\n\nsprite.graphics.begin_fill(color=ap.Color("#f0a"))\nsprite.graphics.draw_rect(x=150, y=50, width=50, height=50)\n\nap.display_on_jupyter(html_file_name="jupyter_sample_1.html")\n```',  # noqa
    ##################################################
    "![](_static/jupyter_notebook_interface.png)": "![](_static/jupyter_notebook_interface.png)",  # noqa
    ##################################################
    "Also, this interface can use on the JupyterLab:": "このインターフェイスはJupyterLabもサポートしています:",  # noqa
    ##################################################
    "![](_static/jupyterlab_interface.png)": "![](_static/jupyterlab_interface.png)",
    ##################################################
    "## display_on_jupyter API": "## display_on_jupyter API",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Save the overall HTML and display it on the Jupyter.<hr>": "HTML全体を保存し結果をJupyter上で表示します。<hr>",  # noqa
    ##################################################
    "**[Parameters]**": "**[引数]**",
    ##################################################
    "- `html_file_name`: str, default 'index.html'": "- `html_file_name`: str, default 'index.html'",  # noqa
    ##################################################
    "  - The output HTML file name.": "  - 出力されるHTMLのファイル名。",
    ##################################################
    "- `minify`: bool, default True": "- `minify`: bool, default True",
    ##################################################
    "  - Boolean value whether minify a HTML or not. False setting is useful when debugging.": "  - HTMLを最小化（minify）するかどうかの真偽値。Falseの設定はデバッグ時などに役に立つことがあります。",  # noqa
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Notes]**": "**[特記事項]**",
    ##################################################
    "Currently, this interface does not support Jupyter on the VS Code. This interface requires the Jupyter library (e.g., `notebook` package).": "現在このインターフェイスはVS Code上のJupyterをサポートしていません。また、このインターフェイスは事前のJupyterのライブラリのインストールが必要です（例 : `notebook`パッケージなど）。",  # noqa
}



"""The mix-in class implementation for the `red_color` property.
"""

from typing import cast

from apysc._html.debug_mode import add_debug_info_setting
from apysc._type.int import Int
from apysc._validation import arg_validation_decos


class RedColorMixIn:
    @property
    @add_debug_info_setting(module_name=__name__)
    def red_color(self) -> Int:
        """
        Get a red color integer value (0 to 255).

        Returns
        -------
        red_color : Int
            Red color integer value (0 to 255).

        References
        ----------
        - Color class red_color property
            - https://simon-ritchie.github.io/apysc/en/red_color.html

        Examples
        --------
        >>> import apysc as ap
        >>> color: ap.Color = ap.Color("#00aaff")
        >>> red_color: ap.Int = color.red_color
        >>> red_color
        Int(0)

        >>> color = ap.Color("#ff00aa")
        >>> red_color = color.red_color
        >>> red_color
        Int(255)

        >>> color.red_color = ap.Int(0)
        >>> red_color = color.red_color
        >>> red_color
        Int(0)
        """
        from apysc._color.color import Color
        from apysc._expression import expression_data_util
        from apysc._type.variable_name_suffix_utils import (
            get_attr_or_variable_name_suffix,
        )
        from apysc._validation import variable_name_validation

        suffix: str = get_attr_or_variable_name_suffix(
            instance=self, value_identifier="red_color"
        )
        red_color: Int = Int(0, variable_name_suffix=suffix)
        color_py_str: str = "#000000"
        if isinstance(self, Color):
            color_py_str = self._value._value
        red_color._value = int(color_py_str[1:3], 16)
        variable_name: str = variable_name_validation.validate_variable_name_mixin_type(
            instance=self,
        ).variable_name

        expression: str = (
            f"{red_color.variable_name} = "
            f"parseInt({variable_name}.substring(1, 3), 16);"
        )
        expression_data_util.append_js_expression(expression=expression)
        return red_color

    @red_color.setter
    @arg_validation_decos.is_color(arg_position_index=0, optional=False)
    @arg_validation_decos.is_apysc_integer(arg_position_index=1)
    @arg_validation_decos.is_uint8_range(arg_position_index=1)
    @add_debug_info_setting(module_name=__name__)
    def red_color(self, red_color: Int) -> None:
        """
        Set a red color integer value (0 to 255).

        Parameters
        ----------
        red_color : Int
            Red color integer value (0 to 255).

        References
        ----------
        - Color class red_color property
            - https://simon-ritchie.github.io/apysc/en/red_color.html

        Examples
        --------
        >>> import apysc as ap
        >>> color: ap.Color = ap.Color("#00aaff")
        >>> red_color: ap.Int = color.red_color
        >>> red_color
        Int(0)

        >>> color = ap.Color("#ff00aa")
        >>> red_color = color.red_color
        >>> red_color
        Int(255)

        >>> color.red_color = ap.Int(0)
        >>> red_color = color.red_color
        >>> red_color
        Int(0)
        """
        from apysc._color import color_util
        from apysc._color.color import Color
        from apysc._expression import expression_data_util
        from apysc._type.string import String

        self_color: Color = cast(Color, self)
        red_py_str: str = color_util.get_hex_str_from_int(color_int=red_color)
        self_color._value._value = f"#{red_py_str}{self_color._value._value[3:]}"
        tail_color_str: String = self_color._value.slice(start=3)
        red_color_str: String = color_util.get_hex_apysc_string_from_int(
            color_int=red_color, variable_name_suffix=red_color._variable_name_suffix
        )
        expression: str = (
            f'{self_color.variable_name} = "#" + {red_color_str.variable_name}'
            f" + {tail_color_str.variable_name};"
        )
        expression_data_util.append_js_expression(expression=expression)



"""The class implementation for the outlined `perm_camera_mic` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialPermCameraMicOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `perm_camera_mic` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M12 6c-1.1 0-2 .9-2 2v4c0 1.1.9 2 2 2s2-.9 2-2V8c0-1.1-.9-2-2-2zm8-1h-3.17l-1.86-2H8.96L7.17 5H4c-1.1 0-2 .9-2 2v12c0 1.1.9 2 2 2h16c1.1 0 2-.9 2-2V7c0-1.1-.9-2-2-2zm0 14h-7v-1.09c2.83-.48 5-2.94 5-5.91h-2c0 2.21-1.79 4-4 4s-4-1.79-4-4H6c0 2.97 2.17 5.43 5 5.91V19H4V7h4.21l.59-.65L10.04 5h4.24l1.24 1.35.59.65H20v12z"/></svg>'  # noqa



"""The interface implementation for the x-coordinate.
"""

from abc import ABC
from abc import abstractmethod
from typing import Union

from apysc._type.number import Number


class XInterface(ABC):
    _x: Number

    @property
    @abstractmethod
    def x(self) -> Number:
        """
        Get an x-coordinate.
        """

    @x.setter
    @abstractmethod
    def x(self, value: Number) -> None:
        """
        Update x-coordinate.

        Parameters
        ----------
        value : Number
            X-coordinate value.
        """

    @abstractmethod
    def _update_x_and_skip_appending_exp(self, *, x: Union[float, Number]) -> None:
        """
        Update an x-coordinate and skip appending an expression.

        Parameters
        ----------
        x : float or Number
            X-coordinate value.
        """

    @abstractmethod
    def _initialize_x_if_not_initialized(self) -> None:
        """
        Initialize the _x attribute if this instance does not
        initialize it yet.
        """



"""The interface class implementation for the `_copy` method.
"""

from abc import abstractmethod
from typing import Generic
from typing import TypeVar

_SelfType = TypeVar("_SelfType", bound="CopyInterface")


class CopyInterface(Generic[_SelfType]):
    @abstractmethod
    def copy(self) -> _SelfType:
        """
        Make a deep copy of this instance.
        """



# pyright: reportGeneralTypeIssues=false

"""Implementations for Sprite class.
"""

from typing_extensions import final

from apysc._display import graphics
from apysc._display.child_mixin import ChildMixIn
from apysc._display.css_mixin import CssMixIn
from apysc._display.display_object import DisplayObject
from apysc._display.get_bounds_mixin import GetBoundsMixIn
from apysc._display.set_overflow_visible_setting_mixin import (
    SetOverflowVisibleSettingMixIn,
)
from apysc._display.use_hand_cursor_mixin import UseHandCursorMixIn
from apysc._display.x_mixin import XMixIn
from apysc._display.y_mixin import YMixIn
from apysc._event.enter_frame_mixin import EnterFrameMixIn
from apysc._html.debug_mode import add_debug_info_setting
from apysc._loop.initialize_with_base_value_interface import (
    InitializeWithBaseValueInterface,
)
from apysc._type.revert_mixin import RevertMixIn
from apysc._type.variable_name_suffix_mixin import VariableNameSuffixMixIn
from apysc._validation import arg_validation_decos

_Graphics = graphics.Graphics


class Sprite(
    XMixIn,
    YMixIn,
    EnterFrameMixIn,
    SetOverflowVisibleSettingMixIn,
    CssMixIn,
    GetBoundsMixIn,
    UseHandCursorMixIn,
    DisplayObject,
    ChildMixIn,
    RevertMixIn,
    VariableNameSuffixMixIn,
    InitializeWithBaseValueInterface,
):
    """
    This class is for the basic display object that
    can be a parent.

    References
    ----------
    - Sprite
        - https://simon-ritchie.github.io/apysc/en/sprite.html

    Examples
    --------
    >>> import apysc as ap
    >>> stage: ap.Stage = ap.Stage()
    >>> sprite_1: ap.Sprite = ap.Sprite()
    >>> # Create the sprite child rectangle
    >>> sprite_1.graphics.begin_fill(color=ap.Color("#0af"))
    >>> rect: ap.Rectangle = sprite_1.graphics.draw_rect(
    ...     x=50, y=50, width=50, height=50
    ... )
    >>> sprite_1.graphics.contains(rect)
    Boolean(True)

    >>> # Move the created rectangle to the other sprite
    >>> sprite_2: ap.Sprite = ap.Sprite()
    >>> sprite_2.add_child(rect)
    >>> sprite_1.graphics.contains(rect)
    Boolean(False)
    >>> sprite_2.contains(rect)
    Boolean(True)

    >>> # Move the sprite container
    >>> sprite_2.x = ap.Number(50)
    >>> sprite_2.x
    Number(50.0)
    """

    graphics: "_Graphics"

    @arg_validation_decos.is_builtin_string(arg_position_index=1, optional=True)
    @arg_validation_decos.is_builtin_string(arg_position_index=2, optional=False)
    @add_debug_info_setting(module_name=__name__)
    def __init__(
        self, *, variable_name: str = "", variable_name_suffix: str = ""
    ) -> None:
        """
        Create a basic display object that can be a parent.

        Parameters
        ----------
        variable_name : str, default '
            Variable name of this instance. A js expression uses
            this setting. It is unnecessary to specify any
            string except when instantiating the `Sprite` subclass.
        variable_name_suffix : str, default ""
            A JavaScript variable name suffix string.
            This setting is sometimes useful for JavaScript debugging.

        References
        ----------
        - Sprite
            - https://simon-ritchie.github.io/apysc/en/sprite.html

        Examples
        --------
        >>> import apysc as ap
        >>> stage: ap.Stage = ap.Stage()
        >>> sprite_1: ap.Sprite = ap.Sprite()
        >>> # Create the sprite child rectangle
        >>> sprite_1.graphics.begin_fill(color=ap.Color("#0af"))
        >>> rect: ap.Rectangle = sprite_1.graphics.draw_rect(
        ...     x=50, y=50, width=50, height=50
        ... )
        >>> sprite_1.graphics.contains(rect)
        Boolean(True)

        >>> # Move the created rectangle to the other sprite
        >>> sprite_2: ap.Sprite = ap.Sprite()
        >>> sprite_2.add_child(rect)
        >>> sprite_1.graphics.contains(rect)
        Boolean(False)
        >>> sprite_2.contains(rect)
        Boolean(True)

        >>> # Move the sprite container
        >>> sprite_2.x = ap.Number(50)
        >>> sprite_2.x
        Number(50.0)
        """
        from apysc._display.stage import Stage
        from apysc._display.stage import get_stage
        from apysc._expression import expression_variables_util
        from apysc._expression import var_names
        from apysc._type.array import Array

        self._variable_name_suffix = variable_name_suffix
        stage: Stage = get_stage()
        if variable_name == "":
            variable_name = expression_variables_util.get_next_variable_name(
                type_name=var_names.SPRITE
            )

        suffix: str = self._get_attr_or_variable_name_suffix(
            value_identifier="children"
        )
        self._children = Array([], variable_name_suffix=suffix)

        super(Sprite, self).__init__(variable_name=variable_name)
        self._append_constructor_expression()
        suffix = self._get_attr_or_variable_name_suffix(value_identifier="graphics")
        self.graphics = graphics.Graphics(parent=self, variable_name_suffix=suffix)
        stage.add_child(child=self)
        self._set_overflow_visible_setting()

    @final
    @add_debug_info_setting(module_name=__name__)
    def _append_constructor_expression(self) -> None:
        """
        Append Sprite constructor expression.
        """
        from apysc._display.stage import Stage
        from apysc._display.stage import get_stage
        from apysc._expression import expression_data_util

        stage: Stage = get_stage()
        expression: str = (
            f"\nvar {self.variable_name} = {stage.variable_name}.nested();"
        )
        expression_data_util.append_js_expression(expression=expression)

    def _make_snapshot(self, *, snapshot_name: str) -> None:
        """
        Make values' snapshot.

        Parameters
        ----------
        snapshot_name : str
            Target snapshot name.
        """
        if self._snapshot_exists(snapshot_name=snapshot_name):
            return
        self.graphics._run_all_make_snapshot_methods(snapshot_name=snapshot_name)

    def _revert(self, *, snapshot_name: str) -> None:
        """
        Revert values if a snapshot exists.

        Parameters
        ----------
        snapshot_name : str
            Target snapshot name.
        """
        if not self._snapshot_exists(snapshot_name=snapshot_name):
            return
        self.graphics._run_all_revert_methods(snapshot_name=snapshot_name)

    def __repr__(self) -> str:
        """
        Get a string representation of this instance (for the sake of
        debugging).

        Returns
        -------
        repr_str : str
            Type name and variable name will be set
            (e.g., `Sprite("<variable_name>")`).
        """
        repr_str: str = f'{Sprite.__name__}("{self.variable_name}")'
        return repr_str

    @classmethod
    @final
    def _initialize_with_base_value(cls) -> "Sprite":
        """
        Initialize this class with a base value(s).

        Returns
        -------
        sprite : Sprite
            An initialized sprite instance.
        """
        from apysc._type.boolean import Boolean

        sprite: Sprite = Sprite()
        sprite.visible = Boolean(False)
        return sprite



"""Class implementation for the event binding expression-related mix-in.
"""

from typing_extensions import final

from apysc._event.mouse_event_type import MouseEventType
from apysc._html.debug_mode import add_debug_info_setting


class MouseEventBindingExpressionMixin:
    @final
    @add_debug_info_setting(module_name=__name__)
    def _append_mouse_event_binding_expression(
        self, *, name: str, mouse_event_type: MouseEventType
    ) -> None:
        """
        Append a mouse event binding expression.

        Parameters
        ----------
        name : str
            Handler's name.
        mouse_event_type : MouseEventType
            Event type to bind.
        """
        from apysc._expression import expression_data_util
        from apysc._type.variable_name_mixin import VariableNameMixIn
        from apysc._validation.variable_name_validation import (
            validate_variable_name_mixin_type,
        )

        self_instance: VariableNameMixIn = validate_variable_name_mixin_type(
            instance=self
        )
        expression: str = (
            f"{self_instance.variable_name}.{mouse_event_type.value}({name});"
        )
        expression_data_util.append_js_expression(expression=expression)



"""The class implementation for the `accessible_forward` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialAccessibleForwardIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `accessible_forward` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0z" fill="none"/><circle cx="17" cy="4.54" r="2"/><path d="M14 17h-2c0 1.65-1.35 3-3 3s-3-1.35-3-3 1.35-3 3-3v-2c-2.76 0-5 2.24-5 5s2.24 5 5 5 5-2.24 5-5zm3-3.5h-1.86l1.67-3.67C17.42 8.5 16.44 7 14.96 7h-5.2c-.81 0-1.54.47-1.87 1.2L7.22 10l1.92.53L9.79 9H12l-1.83 4.1c-.6 1.33.39 2.9 1.85 2.9H17v5h2v-5.5c0-1.1-.9-2-2-2z"/></svg>'  # noqa



"""Class implementation for the `revert`-related interface.
"""

from abc import ABC
from abc import abstractmethod


class RevertInterface(ABC):
    @abstractmethod
    def _make_snapshot(self, *, snapshot_name: str) -> None:
        """
        Make a value snapshot.

        Parameters
        ----------
        snapshot_name : str
            Target snapshot name.
        """

    @abstractmethod
    def _revert(self, *, snapshot_name: str) -> None:
        """
        Revert values if a snapshot exists.

        Parameters
        ----------
        snapshot_name : str
            Target snapshot name.
        """



"""The class implementation for the outlined `donut_small` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialDonutSmallOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `donut_small` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M14.82 11h7.13c-.47-4.72-4.23-8.48-8.95-8.95v7.13c.85.31 1.51.97 1.82 1.82zM15 4.58C17 5.4 18.6 7 19.42 9h-3.43c-.28-.37-.62-.71-.99-.99V4.58zM2 12c0 5.19 3.95 9.45 9 9.95v-7.13C9.84 14.4 9 13.3 9 12c0-1.3.84-2.4 2-2.82V2.05c-5.05.5-9 4.76-9 9.95zm7-7.42v3.44c-1.23.92-2 2.39-2 3.98 0 1.59.77 3.06 2 3.99v3.44C6.04 18.24 4 15.35 4 12c0-3.35 2.04-6.24 5-7.42zm4 10.24v7.13c4.72-.47 8.48-4.23 8.95-8.95h-7.13c-.31.85-.97 1.51-1.82 1.82zm2 1.17c.37-.28.71-.61.99-.99h3.43C18.6 17 17 18.6 15 19.42v-3.43z"/></svg>'  # noqa



"""The class implementation for the outlined `speaker_notes_off` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialSpeakerNotesOffOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `speaker_notes_off` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M20 4v12h-1.34l1.91 1.91C21.39 17.66 22 16.9 22 16V4c0-1.1-.9-2-2-2H4.66l2 2H20zM6 12h2v2H6zm12-3h-6.34l2 2H18zm0-3h-8v1.34l.66.66H18zM1.41 1.59L0 3l2.01 2.01L2 22l4-4h9l5.73 5.73 1.41-1.41L1.41 1.59zM5.17 16L4 17.17V7l2 2v2h2l5 5H5.17z"/></svg>'  # noqa



"""The class implementation for the `camera_enhance` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialCameraEnhanceIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `camera_enhance` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M9 3L7.17 5H4c-1.1 0-2 .9-2 2v12c0 1.1.9 2 2 2h16c1.1 0 2-.9 2-2V7c0-1.1-.9-2-2-2h-3.17L15 3H9zm3 15c-2.76 0-5-2.24-5-5s2.24-5 5-5 5 2.24 5 5-2.24 5-5 5z"/><path d="M12 17l1.25-2.75L16 13l-2.75-1.25L12 9l-1.25 2.75L8 13l2.75 1.25z"/></svg>'  # noqa



"""The class implementation for the `shopping_basket` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialShoppingBasketIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `shopping_basket` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0z" fill="none"/><path d="M17.21 9l-4.38-6.56c-.19-.28-.51-.42-.83-.42-.32 0-.64.14-.83.43L6.79 9H2c-.55 0-1 .45-1 1 0 .09.01.18.04.27l2.54 9.27c.23.84 1 1.46 1.92 1.46h13c.92 0 1.69-.62 1.93-1.46l2.54-9.27L23 10c0-.55-.45-1-1-1h-4.79zM9 9l3-4.4L15 9H9zm3 8c-1.1 0-2-.9-2-2s.9-2 2-2 2 .9 2 2-.9 2-2 2z"/></svg>'  # noqa



"""The class implementation for the outlined `text_rotation_angledown` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialTextRotationAngledownOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `text_rotation_angledown` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0zm0 0h24v24H0V0zm0 0h24v24H0V0z" fill="none"/><path d="M15 21v-4.24l-1.41 1.41-9.2-9.19-1.41 1.41 9.19 9.19L10.76 21H15zM11.25 8.48l3.54 3.54-.92 2.19 1.48 1.48 4.42-11.14-1.06-1.05L7.57 7.92 9.06 9.4l2.19-.92zm6.59-3.05l-2.23 4.87-2.64-2.64 4.87-2.23z"/></svg>'  # noqa



"""The class implementation for the outlined `print` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialPrintOutlinedIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the outlined `print` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" height="24" viewBox="0 0 24 24" width="24"><path d="M0 0h24v24H0V0z" fill="none"/><path d="M19 8h-1V3H6v5H5c-1.66 0-3 1.34-3 3v6h4v4h12v-4h4v-6c0-1.66-1.34-3-3-3zM8 5h8v3H8V5zm8 12v2H8v-4h8v2zm2-2v-2H6v2H4v-4c0-.55.45-1 1-1h14c.55 0 1 .45 1 1v4h-2z"/><circle cx="18" cy="11.5" r="1"/></svg>'  # noqa



"""The class implementation for the `remove_from_queue` material icon.
"""

from apysc._display.fixed_html_svg_icon_base import FixedHtmlSvgIconBase


class MaterialRemoveFromQueueIcon(FixedHtmlSvgIconBase):
    """
    The class implementation for the `remove_from_queue` material icon.
    """

    def _get_fixed_svg_icon_html(self) -> str:
        """
        Get a fixed SVG icon HTML string.

        Returns
        -------
        fixed_svg_icon_html : str
            Fixed SVG icon HTML string.

        References
        ----------
        - Material icon document
            - https://simon-ritchie.github.io/apysc/en/material_icon.html
        - Material Symbols & Icons, APACHE LICENSE, VERSION 2.0
            - https://fonts.google.com/icons?icon.size=24&icon.color=%23e8eaed
            - https://www.apache.org/licenses/LICENSE-2.0.html
        """
        return '<svg xmlns="http://www.w3.org/2000/svg" enable-background="new 0 0 24 24" height="24" viewBox="0 0 24 24" width="24"><g><rect fill="none" height="24" width="24" x="0"/></g><g><g><g><path d="M21,3H3C1.89,3,1,3.89,1,5v12c0,1.1,0.89,2,2,2h5v2h8v-2h5c1.1,0,1.99-0.9,1.99-2L23,5C23,3.89,22.1,3,21,3z M21,17H3V5 h18V17z M16,10v2H8v-2H16z"/></g></g></g></svg>'  # noqa



"""This module is for the translation mapping data of the
following document:

Document file: green_color.md
Language: jp
"""

from typing import Dict

MAPPING: Dict[str, str] = {
    ##################################################
    "# Color class green_color property": "# Color クラスの green_color プロパティ",
    ##################################################
    "This page explains the `Color` class `green_color` property.": "このページでは`Color`クラスの`green_color`プロパティについて説明します。",  # noqa
    ##################################################
    "## What property is this?": "## 属性の概要",
    ##################################################
    "The `green_color` property returns or sets a green color `ap.Int` value.": "`green_color`プロパティは緑色の色の`ap.Int`型の値の返却もしくは設定を行います。",  # noqa
    ##################################################
    "This value takes the range from 0 to 255.": "この値は0～255の範囲を取ります。",
    ##################################################
    "## Basic usage": "## 基本的な使い方",
    ##################################################
    "The following example shows how to use the `green_color` getter and setter interfaces:": "以下のコードでは`green_color`のgetterとsetterの各インターフェイスの例を示します:",  # noqa
    ##################################################
    '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    stage_width=0,\n    stage_height=0,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\n\ncolor: ap.Color = ap.Color("#aa00ff")\ngreen_color: ap.Int = color.green_color\nap.assert_equal(green_color, 0)\n\ncolor = ap.Color("#00ffaa")\ngreen_color = color.green_color\nap.assert_equal(green_color, 255)\n\ncolor.green_color = ap.Int(0)\ngreen_color = color.green_color\nap.assert_equal(green_color, 0)\n\ncolor.green_color = ap.Int(255)\ngreen_color = color.green_color\nap.assert_equal(green_color, 255)\n\nap.save_overall_html(dest_dir_path="./green_color_basic_usage/")\n```': '```py\n# runnable\nimport apysc as ap\n\nstage: ap.Stage = ap.Stage(\n    stage_width=0,\n    stage_height=0,\n    background_color=ap.Color("#333"),\n    stage_elem_id="stage",\n)\n\ncolor: ap.Color = ap.Color("#aa00ff")\ngreen_color: ap.Int = color.green_color\nap.assert_equal(green_color, 0)\n\ncolor = ap.Color("#00ffaa")\ngreen_color = color.green_color\nap.assert_equal(green_color, 255)\n\ncolor.green_color = ap.Int(0)\ngreen_color = color.green_color\nap.assert_equal(green_color, 0)\n\ncolor.green_color = ap.Int(255)\ngreen_color = color.green_color\nap.assert_equal(green_color, 255)\n\nap.save_overall_html(dest_dir_path="./green_color_basic_usage/")\n```',  # noqa
    ##################################################
    "## green_color property API": "## green_color 属性のAPI",
    ##################################################
    '<span class="inconspicuous-txt">Note: the document build script generates and updates this API document section automatically. Maybe this section is duplicated compared with previous sections.</span>': '<span class="inconspicuous-txt">特記事項: このAPIドキュメントはドキュメントビルド用のスクリプトによって自動で生成・同期されています。そのためもしかしたらこの節の内容は前節までの内容と重複している場合があります。</span>',  # noqa
    ##################################################
    "**[Interface summary]**": "**[インターフェイス概要]**",
    ##################################################
    "Get a green color integer value (0 to 255).<hr>": "緑色の整数値（0～255）を取得します。<hr>",
    ##################################################
    "**[Returns]**": "**[返却値]**",
    ##################################################
    "- `green_color`: Int": "- `green_color`: Int",
    ##################################################
    "  - Green color integer value (0 to 255).": "  - 緑色の整数値（0～255）。",
    ##################################################
    "<hr>": "<hr>",
    ##################################################
    "**[Examples]**": "**[コードサンプル]**",
    ##################################################
    '```py\n>>> import apysc as ap\n>>> _ = ap.Stage(\n...     background_color=ap.Color("#333"),\n...     stage_elem_id="stage",\n... )\n>>> color: ap.Color = ap.Color("#aa00ff")\n>>> green_color: ap.Int = color.green_color\n>>> green_color\nInt(0)\n\n>>> color = ap.Color("#00ffaa")\n>>> green_color = color.green_color\n>>> green_color\nInt(255)\n\n>>> color.green_color = ap.Int(0)\n>>> green_color = color.green_color\n>>> green_color\nInt(0)\n\n>>> color.green_color = ap.Int(255)\n>>> green_color = color.green_color\n>>> green_color\nInt(255)\n```': '```py\n>>> import apysc as ap\n>>> _ = ap.Stage(\n...     background_color=ap.Color("#333"),\n...     stage_elem_id="stage",\n... )\n>>> color: ap.Color = ap.Color("#aa00ff")\n>>> green_color: ap.Int = color.green_color\n>>> green_color\nInt(0)\n\n>>> color = ap.Color("#00ffaa")\n>>> green_color = color.green_color\n>>> green_color\nInt(255)\n\n>>> color.green_color = ap.Int(0)\n>>> green_color = color.green_color\n>>> green_color\nInt(0)\n\n>>> color.green_color = ap.Int(255)\n>>> green_color = color.green_color\n>>> green_color\nInt(255)\n```',  # noqa
}
